@@ -3,11 +3,11 @@ Package for data anonymization of different data types
 such as tabular, text, images and sound. 
 '''
 
-__version__ =  "0.1.3"
+__version__ =  "0.1.9"
 
 # Check if all dependencies have been installed
 
-hard_dependencies = ("faker", "cape_privacy", "pandas", "numpy")
+hard_dependencies = ("faker", "pandas", "numpy")
 missing_dependencies = []
 
 for dependency in hard_dependencies:
@@ -28,4 +28,4 @@ from anonympy import images
 from anonympy import sound 
 from anonympy import text
 
-__all__ = ["pandas", "tabular", "sound", "text"]
+__all__ = ["pandas", "images", "sound", "text"]
